aboutsummaryrefslogtreecommitdiffstats
path: root/g10/keyserver.c
diff options
context:
space:
mode:
Diffstat (limited to 'g10/keyserver.c')
-rw-r--r--g10/keyserver.c14
1 files changed, 9 insertions, 5 deletions
diff --git a/g10/keyserver.c b/g10/keyserver.c
index 492ce0ce5..48033ab8d 100644
--- a/g10/keyserver.c
+++ b/g10/keyserver.c
@@ -1771,13 +1771,17 @@ keyserver_get_chunk (ctrl_t ctrl, KEYDB_SEARCH_DESC *desc, int ndesc,
never accept or send them but we better protect against rogue
keyservers. */
/* For LDAP servers we reset IMPORT_SELF_SIGS_ONLY unless it has
* been set explicitly. */
options = (opt.keyserver_options.import_options | IMPORT_NO_SECKEY);
if (source && (!strncmp (source, "ldap:", 5)
- || !strncmp (source, "ldaps:", 6))
- && !opt.flags.expl_import_self_sigs_only)
- options &= ~IMPORT_SELF_SIGS_ONLY;
+ || !strncmp (source, "ldaps:", 6)))
+ {
+ if (!opt.flags.expl_import_self_sigs_only)
+ options &= ~IMPORT_SELF_SIGS_ONLY;
+ if (!opt.flags.expl_import_clean)
+ options &= ~IMPORT_CLEAN;
+ }
screenerarg.desc = desc;
screenerarg.ndesc = *r_ndesc_used;
@@ -1771,13 +1771,17 @@ keyserver_get_chunk (ctrl_t ctrl, KEYDB_SEARCH_DESC *desc, int ndesc,
never accept or send them but we better protect against rogue
keyservers. */
- /* For LDAP servers we reset IMPORT_SELF_SIGS_ONLY unless it has
- * been set explicitly. */
+ /* For LDAP servers we reset IMPORT_SELF_SIGS_ONLY and
+ * IMPORT_CLEAN unless they have been set explicitly. */
options = (opt.keyserver_options.import_options | IMPORT_NO_SECKEY);
if (source && (!strncmp (source, "ldap:", 5)